==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/RodzajPobSwiadczenia.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.RodzajOdliczeniaSwiadczenia;
import pl.topteam.dps.enums.RodzajZwrotuSwiadczenia;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class RodzajPobSwiadczenia extends GenericDPSObject {
    /**
     * RODZAJ_POB_SWIADCZENIA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * RODZAJ_POB_SWIADCZENIA.ODLICZENIE_POBYT_DZIEN_ZGONU
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private RodzajOdliczeniaSwiadczenia odliczeniePobytDzienZgonu;

    /**
     * RODZAJ_POB_SWIADCZENIA.ODLICZENIE_POBYT_PO_ZGON
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private RodzajOdliczeniaSwiadczenia odliczeniePobytPoZgon;

    /**
     * RODZAJ_POB_SWIADCZENIA.ODLICZENIE_POBYT_PRZED_ZGON
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private RodzajOdliczeniaSwiadczenia odliczeniePobytPrzedZgon;

    /**
     * RODZAJ_POB_SWIADCZENIA.ZWROT_WYPLATA_DZIEN_ZGONU
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private RodzajZwrotuSwiadczenia zwrotWyplataDzienZgonu;

    /**
     * RODZAJ_POB_SWIADCZENIA.ZWROT_WYPLATA_PO_ZGON
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private RodzajZwrotuSwiadczenia zwrotWyplataPoZgon;

    /**
     * RODZAJ_POB_SWIADCZENIA.ZWROT_WYPLATA_PRZED_ZGON
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private RodzajZwrotuSwiadczenia zwrotWyplataPrzedZgon;

    /**
     * RODZAJ_POB_SWIADCZENIA.KOD
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String kod;

    /**
     * RODZAJ_POB_SWIADCZENIA.TEKST
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String tekst;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return RODZAJ_POB_SWIADCZENIA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * RODZAJ_POB_SWIADCZENIA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return RODZAJ_POB_SWIADCZENIA.ODLICZENIE_POBYT_DZIEN_ZGONU
     * @mbggenerated 2014-03-10 10:45:37
     */
    public RodzajOdliczeniaSwiadczenia getOdliczeniePobytDzienZgonu() {
        return odliczeniePobytDzienZgonu;
    }

    /**
     * RODZAJ_POB_SWIADCZENIA.ODLICZENIE_POBYT_DZIEN_ZGONU
     *
     * @param odliczeniePobytDzienZgonu
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOdliczeniePobytDzienZgonu(RodzajOdliczeniaSwiadczenia odliczeniePobytDzienZgonu) {
        this.odliczeniePobytDzienZgonu = odliczeniePobytDzienZgonu;
    }

    /**
     * @return RODZAJ_POB_SWIADCZENIA.ODLICZENIE_POBYT_PO_ZGON
     * @mbggenerated 2014-03-10 10:45:37
     */
    public RodzajOdliczeniaSwiadczenia getOdliczeniePobytPoZgon() {
        return odliczeniePobytPoZgon;
    }

    /**
     * RODZAJ_POB_SWIADCZENIA.ODLICZENIE_POBYT_PO_ZGON
     *
     * @param odliczeniePobytPoZgon
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOdliczeniePobytPoZgon(RodzajOdliczeniaSwiadczenia odliczeniePobytPoZgon) {
        this.odliczeniePobytPoZgon = odliczeniePobytPoZgon;
    }

    /**
     * @return RODZAJ_POB_SWIADCZENIA.ODLICZENIE_POBYT_PRZED_ZGON
     * @mbggenerated 2014-03-10 10:45:37
     */
    public RodzajOdliczeniaSwiadczenia getOdliczeniePobytPrzedZgon() {
        return odliczeniePobytPrzedZgon;
    }

    /**
     * RODZAJ_POB_SWIADCZENIA.ODLICZENIE_POBYT_PRZED_ZGON
     *
     * @param odliczeniePobytPrzedZgon
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOdliczeniePobytPrzedZgon(RodzajOdliczeniaSwiadczenia odliczeniePobytPrzedZgon) {
        this.odliczeniePobytPrzedZgon = odliczeniePobytPrzedZgon;
    }

    /**
     * @return RODZAJ_POB_SWIADCZENIA.ZWROT_WYPLATA_DZIEN_ZGONU
     * @mbggenerated 2014-03-10 10:45:37
     */
    public RodzajZwrotuSwiadczenia getZwrotWyplataDzienZgonu() {
        return zwrotWyplataDzienZgonu;
    }

    /**
     * RODZAJ_POB_SWIADCZENIA.ZWROT_WYPLATA_DZIEN_ZGONU
     *
     * @param zwrotWyplataDzienZgonu
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setZwrotWyplataDzienZgonu(RodzajZwrotuSwiadczenia zwrotWyplataDzienZgonu) {
        this.zwrotWyplataDzienZgonu = zwrotWyplataDzienZgonu;
    }

    /**
     * @return RODZAJ_POB_SWIADCZENIA.ZWROT_WYPLATA_PO_ZGON
     * @mbggenerated 2014-03-10 10:45:37
     */
    public RodzajZwrotuSwiadczenia getZwrotWyplataPoZgon() {
        return zwrotWyplataPoZgon;
    }

    /**
     * RODZAJ_POB_SWIADCZENIA.ZWROT_WYPLATA_PO_ZGON
     *
     * @param zwrotWyplataPoZgon
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setZwrotWyplataPoZgon(RodzajZwrotuSwiadczenia zwrotWyplataPoZgon) {
        this.zwrotWyplataPoZgon = zwrotWyplataPoZgon;
    }

    /**
     * @return RODZAJ_POB_SWIADCZENIA.ZWROT_WYPLATA_PRZED_ZGON
     * @mbggenerated 2014-03-10 10:45:37
     */
    public RodzajZwrotuSwiadczenia getZwrotWyplataPrzedZgon() {
        return zwrotWyplataPrzedZgon;
    }

    /**
     * RODZAJ_POB_SWIADCZENIA.ZWROT_WYPLATA_PRZED_ZGON
     *
     * @param zwrotWyplataPrzedZgon
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setZwrotWyplataPrzedZgon(RodzajZwrotuSwiadczenia zwrotWyplataPrzedZgon) {
        this.zwrotWyplataPrzedZgon = zwrotWyplataPrzedZgon;
    }

    /**
     * @return RODZAJ_POB_SWIADCZENIA.KOD
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getKod() {
        return kod;
    }

    /**
     * RODZAJ_POB_SWIADCZENIA.KOD
     *
     * @param kod
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKod(String kod) {
        this.kod = kod == null ? null : kod.trim();
    }

    /**
     * @return RODZAJ_POB_SWIADCZENIA.TEKST
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getTekst() {
        return tekst;
    }

    /**
     * RODZAJ_POB_SWIADCZENIA.TEKST
     *
     * @param tekst
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTekst(String tekst) {
        this.tekst = tekst == null ? null : tekst.trim();
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        RodzajPobSwiadczenia other = (RodzajPobSwiadczenia) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getOdliczeniePobytDzienZgonu() == null ? other.getOdliczeniePobytDzienZgonu() == null : this.getOdliczeniePobytDzienZgonu().equals(other.getOdliczeniePobytDzienZgonu()))
            && (this.getOdliczeniePobytPoZgon() == null ? other.getOdliczeniePobytPoZgon() == null : this.getOdliczeniePobytPoZgon().equals(other.getOdliczeniePobytPoZgon()))
            && (this.getOdliczeniePobytPrzedZgon() == null ? other.getOdliczeniePobytPrzedZgon() == null : this.getOdliczeniePobytPrzedZgon().equals(other.getOdliczeniePobytPrzedZgon()))
            && (this.getZwrotWyplataDzienZgonu() == null ? other.getZwrotWyplataDzienZgonu() == null : this.getZwrotWyplataDzienZgonu().equals(other.getZwrotWyplataDzienZgonu()))
            && (this.getZwrotWyplataPoZgon() == null ? other.getZwrotWyplataPoZgon() == null : this.getZwrotWyplataPoZgon().equals(other.getZwrotWyplataPoZgon()))
            && (this.getZwrotWyplataPrzedZgon() == null ? other.getZwrotWyplataPrzedZgon() == null : this.getZwrotWyplataPrzedZgon().equals(other.getZwrotWyplataPrzedZgon()))
            && (this.getKod() == null ? other.getKod() == null : this.getKod().equals(other.getKod()))
            && (this.getTekst() == null ? other.getTekst() == null : this.getTekst().equals(other.getTekst()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getOdliczeniePobytDzienZgonu() == null) ? 0 : getOdliczeniePobytDzienZgonu().hashCode());
        result = prime * result + ((getOdliczeniePobytPoZgon() == null) ? 0 : getOdliczeniePobytPoZgon().hashCode());
        result = prime * result + ((getOdliczeniePobytPrzedZgon() == null) ? 0 : getOdliczeniePobytPrzedZgon().hashCode());
        result = prime * result + ((getZwrotWyplataDzienZgonu() == null) ? 0 : getZwrotWyplataDzienZgonu().hashCode());
        result = prime * result + ((getZwrotWyplataPoZgon() == null) ? 0 : getZwrotWyplataPoZgon().hashCode());
        result = prime * result + ((getZwrotWyplataPrzedZgon() == null) ? 0 : getZwrotWyplataPrzedZgon().hashCode());
        result = prime * result + ((getKod() == null) ? 0 : getKod().hashCode());
        result = prime * result + ((getTekst() == null) ? 0 : getTekst().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", odliczeniePobytDzienZgonu=").append(odliczeniePobytDzienZgonu);
        sb.append(", odliczeniePobytPoZgon=").append(odliczeniePobytPoZgon);
        sb.append(", odliczeniePobytPrzedZgon=").append(odliczeniePobytPrzedZgon);
        sb.append(", zwrotWyplataDzienZgonu=").append(zwrotWyplataDzienZgonu);
        sb.append(", zwrotWyplataPoZgon=").append(zwrotWyplataPoZgon);
        sb.append(", zwrotWyplataPrzedZgon=").append(zwrotWyplataPrzedZgon);
        sb.append(", kod=").append(kod);
        sb.append(", tekst=").append(tekst);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/RodzajPobSwiadczenia.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.RodzajOdliczeniaSwiadczenia;
import pl.topteam.dps.enums.RodzajZwrotuSwiadczenia;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class RodzajPobSwiadczenia extends GenericDPSObject {
    /**
     * RODZAJ_POB_SWIADCZENIA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * RODZAJ_POB_SWIADCZENIA.ODLICZENIE_POBYT_DZIEN_ZGONU
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private RodzajOdliczeniaSwiadczenia odliczeniePobytDzienZgonu;

    /**
     * RODZAJ_POB_SWIADCZENIA.ODLICZENIE_POBYT_PO_ZGON
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private RodzajOdliczeniaSwiadczenia odliczeniePobytPoZgon;

    /**
     * RODZAJ_POB_SWIADCZENIA.ODLICZENIE_POBYT_PRZED_ZGON
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private RodzajOdliczeniaSwiadczenia odliczeniePobytPrzedZgon;

    /**
     * RODZAJ_POB_SWIADCZENIA.ZWROT_WYPLATA_DZIEN_ZGONU
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private RodzajZwrotuSwiadczenia zwrotWyplataDzienZgonu;

    /**
     * RODZAJ_POB_SWIADCZENIA.ZWROT_WYPLATA_PO_ZGON
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private RodzajZwrotuSwiadczenia zwrotWyplataPoZgon;

    /**
     * RODZAJ_POB_SWIADCZENIA.ZWROT_WYPLATA_PRZED_ZGON
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private RodzajZwrotuSwiadczenia zwrotWyplataPrzedZgon;

    /**
     * RODZAJ_POB_SWIADCZENIA.KOD
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String kod;

    /**
     * RODZAJ_POB_SWIADCZENIA.TEKST
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String tekst;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return RODZAJ_POB_SWIADCZENIA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * RODZAJ_POB_SWIADCZENIA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return RODZAJ_POB_SWIADCZENIA.ODLICZENIE_POBYT_DZIEN_ZGONU
     * @mbggenerated 2014-03-13 16:02:38
     */
    public RodzajOdliczeniaSwiadczenia getOdliczeniePobytDzienZgonu() {
        return odliczeniePobytDzienZgonu;
    }

    /**
     * RODZAJ_POB_SWIADCZENIA.ODLICZENIE_POBYT_DZIEN_ZGONU
     *
     * @param odliczeniePobytDzienZgonu
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOdliczeniePobytDzienZgonu(RodzajOdliczeniaSwiadczenia odliczeniePobytDzienZgonu) {
        this.odliczeniePobytDzienZgonu = odliczeniePobytDzienZgonu;
    }

    /**
     * @return RODZAJ_POB_SWIADCZENIA.ODLICZENIE_POBYT_PO_ZGON
     * @mbggenerated 2014-03-13 16:02:38
     */
    public RodzajOdliczeniaSwiadczenia getOdliczeniePobytPoZgon() {
        return odliczeniePobytPoZgon;
    }

    /**
     * RODZAJ_POB_SWIADCZENIA.ODLICZENIE_POBYT_PO_ZGON
     *
     * @param odliczeniePobytPoZgon
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOdliczeniePobytPoZgon(RodzajOdliczeniaSwiadczenia odliczeniePobytPoZgon) {
        this.odliczeniePobytPoZgon = odliczeniePobytPoZgon;
    }

    /**
     * @return RODZAJ_POB_SWIADCZENIA.ODLICZENIE_POBYT_PRZED_ZGON
     * @mbggenerated 2014-03-13 16:02:38
     */
    public RodzajOdliczeniaSwiadczenia getOdliczeniePobytPrzedZgon() {
        return odliczeniePobytPrzedZgon;
    }

    /**
     * RODZAJ_POB_SWIADCZENIA.ODLICZENIE_POBYT_PRZED_ZGON
     *
     * @param odliczeniePobytPrzedZgon
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOdliczeniePobytPrzedZgon(RodzajOdliczeniaSwiadczenia odliczeniePobytPrzedZgon) {
        this.odliczeniePobytPrzedZgon = odliczeniePobytPrzedZgon;
    }

    /**
     * @return RODZAJ_POB_SWIADCZENIA.ZWROT_WYPLATA_DZIEN_ZGONU
     * @mbggenerated 2014-03-13 16:02:38
     */
    public RodzajZwrotuSwiadczenia getZwrotWyplataDzienZgonu() {
        return zwrotWyplataDzienZgonu;
    }

    /**
     * RODZAJ_POB_SWIADCZENIA.ZWROT_WYPLATA_DZIEN_ZGONU
     *
     * @param zwrotWyplataDzienZgonu
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setZwrotWyplataDzienZgonu(RodzajZwrotuSwiadczenia zwrotWyplataDzienZgonu) {
        this.zwrotWyplataDzienZgonu = zwrotWyplataDzienZgonu;
    }

    /**
     * @return RODZAJ_POB_SWIADCZENIA.ZWROT_WYPLATA_PO_ZGON
     * @mbggenerated 2014-03-13 16:02:38
     */
    public RodzajZwrotuSwiadczenia getZwrotWyplataPoZgon() {
        return zwrotWyplataPoZgon;
    }

    /**
     * RODZAJ_POB_SWIADCZENIA.ZWROT_WYPLATA_PO_ZGON
     *
     * @param zwrotWyplataPoZgon
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setZwrotWyplataPoZgon(RodzajZwrotuSwiadczenia zwrotWyplataPoZgon) {
        this.zwrotWyplataPoZgon = zwrotWyplataPoZgon;
    }

    /**
     * @return RODZAJ_POB_SWIADCZENIA.ZWROT_WYPLATA_PRZED_ZGON
     * @mbggenerated 2014-03-13 16:02:38
     */
    public RodzajZwrotuSwiadczenia getZwrotWyplataPrzedZgon() {
        return zwrotWyplataPrzedZgon;
    }

    /**
     * RODZAJ_POB_SWIADCZENIA.ZWROT_WYPLATA_PRZED_ZGON
     *
     * @param zwrotWyplataPrzedZgon
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setZwrotWyplataPrzedZgon(RodzajZwrotuSwiadczenia zwrotWyplataPrzedZgon) {
        this.zwrotWyplataPrzedZgon = zwrotWyplataPrzedZgon;
    }

    /**
     * @return RODZAJ_POB_SWIADCZENIA.KOD
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getKod() {
        return kod;
    }

    /**
     * RODZAJ_POB_SWIADCZENIA.KOD
     *
     * @param kod
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKod(String kod) {
        this.kod = kod == null ? null : kod.trim();
    }

    /**
     * @return RODZAJ_POB_SWIADCZENIA.TEKST
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getTekst() {
        return tekst;
    }

    /**
     * RODZAJ_POB_SWIADCZENIA.TEKST
     *
     * @param tekst
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTekst(String tekst) {
        this.tekst = tekst == null ? null : tekst.trim();
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        RodzajPobSwiadczenia other = (RodzajPobSwiadczenia) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getOdliczeniePobytDzienZgonu() == null ? other.getOdliczeniePobytDzienZgonu() == null : this.getOdliczeniePobytDzienZgonu().equals(other.getOdliczeniePobytDzienZgonu()))
            && (this.getOdliczeniePobytPoZgon() == null ? other.getOdliczeniePobytPoZgon() == null : this.getOdliczeniePobytPoZgon().equals(other.getOdliczeniePobytPoZgon()))
            && (this.getOdliczeniePobytPrzedZgon() == null ? other.getOdliczeniePobytPrzedZgon() == null : this.getOdliczeniePobytPrzedZgon().equals(other.getOdliczeniePobytPrzedZgon()))
            && (this.getZwrotWyplataDzienZgonu() == null ? other.getZwrotWyplataDzienZgonu() == null : this.getZwrotWyplataDzienZgonu().equals(other.getZwrotWyplataDzienZgonu()))
            && (this.getZwrotWyplataPoZgon() == null ? other.getZwrotWyplataPoZgon() == null : this.getZwrotWyplataPoZgon().equals(other.getZwrotWyplataPoZgon()))
            && (this.getZwrotWyplataPrzedZgon() == null ? other.getZwrotWyplataPrzedZgon() == null : this.getZwrotWyplataPrzedZgon().equals(other.getZwrotWyplataPrzedZgon()))
            && (this.getKod() == null ? other.getKod() == null : this.getKod().equals(other.getKod()))
            && (this.getTekst() == null ? other.getTekst() == null : this.getTekst().equals(other.getTekst()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getOdliczeniePobytDzienZgonu() == null) ? 0 : getOdliczeniePobytDzienZgonu().hashCode());
        result = prime * result + ((getOdliczeniePobytPoZgon() == null) ? 0 : getOdliczeniePobytPoZgon().hashCode());
        result = prime * result + ((getOdliczeniePobytPrzedZgon() == null) ? 0 : getOdliczeniePobytPrzedZgon().hashCode());
        result = prime * result + ((getZwrotWyplataDzienZgonu() == null) ? 0 : getZwrotWyplataDzienZgonu().hashCode());
        result = prime * result + ((getZwrotWyplataPoZgon() == null) ? 0 : getZwrotWyplataPoZgon().hashCode());
        result = prime * result + ((getZwrotWyplataPrzedZgon() == null) ? 0 : getZwrotWyplataPrzedZgon().hashCode());
        result = prime * result + ((getKod() == null) ? 0 : getKod().hashCode());
        result = prime * result + ((getTekst() == null) ? 0 : getTekst().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", odliczeniePobytDzienZgonu=").append(odliczeniePobytDzienZgonu);
        sb.append(", odliczeniePobytPoZgon=").append(odliczeniePobytPoZgon);
        sb.append(", odliczeniePobytPrzedZgon=").append(odliczeniePobytPrzedZgon);
        sb.append(", zwrotWyplataDzienZgonu=").append(zwrotWyplataDzienZgonu);
        sb.append(", zwrotWyplataPoZgon=").append(zwrotWyplataPoZgon);
        sb.append(", zwrotWyplataPrzedZgon=").append(zwrotWyplataPrzedZgon);
        sb.append(", kod=").append(kod);
        sb.append(", tekst=").append(tekst);
        sb.append("]");
        return sb.toString();
    }
}
